Class: ScalewayTem::ActionMailer::Railtie
- Inherits:
-
Rails::Railtie
- Object
- Rails::Railtie
- ScalewayTem::ActionMailer::Railtie
- Defined in:
- lib/scaleway_tem/action_mailer/railtie.rb
Overview
Registers :scaleway_tem with ActionMailer as soon as ActionMailer loads.
on_load rather than an initializer block so the registration happens whether or not the host application eager loads, and without this gem forcing ActionMailer to load in an app that does not use it.